summaryrefslogtreecommitdiffstats
path: root/avahi-core/core.h
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2005-08-21 21:15:47 +0000
committerLennart Poettering <lennart@poettering.net>2005-08-21 21:15:47 +0000
commit15aaf28f0345ed6998ef6eae921c7750c4ce26f9 (patch)
tree06515dc742be8eca223bf6f82d85528d3f6bb499 /avahi-core/core.h
parent041302604374ae779d4d6a1e83b5f738c7be00d0 (diff)
* Beef up host name and address resolvers to notify about RR changes (Similar to what already is available for the service resolver)
git-svn-id: file:///home/lennart/svn/public/avahi/trunk@388 941a03a8-eaeb-0310-b9a0-b1bbd8fe43fe
Diffstat (limited to 'avahi-core/core.h')
-rw-r--r--avahi-core/core.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/avahi-core/core.h b/avahi-core/core.h
index 2f55d73..1cf35fc 100644
--- a/avahi-core/core.h
+++ b/avahi-core/core.h
@@ -506,7 +506,7 @@ typedef void (*AvahiSServiceResolverCallback)(
AvahiSServiceResolver *r,
AvahiIfIndex interface,
AvahiProtocol protocol,
- AvahiResolverEvent event,
+ AvahiResolverEvent event, /**< Is AVAHI_RESOLVER_FOUND when the service was resolved successfully, and everytime it changes. Is AVAHI_RESOLVER_TIMOUT when the service failed to resolve or disappeared. */
const char *name, /**< Service name */
const char *type, /**< Service Type */
const char *domain,
@@ -516,7 +516,7 @@ typedef void (*AvahiSServiceResolverCallback)(
AvahiStringList *txt, /**< TXT record data */
void* userdata);
/** Create a new AvahiSServiceResolver object */
AvahiSServiceResolver *avahi_s_service_resolver_new(
AvahiServer *server,
AvahiIfIndex interface,
@@ -516,7 +516,7 @@ typedef void (*AvahiSServiceResolverCallback)(
AvahiStringList *txt, /**< TXT record data */
void* userdata);
-/** Create a new AvahiSServiceResolver object */
+/** Create a new AvahiSServiceResolver object. The specified callback function will be called with the resolved service data. */
AvahiSServiceResolver *avahi_s_service_resolver_new(
AvahiServer *server,